Struct WriteOnly
pub struct WriteOnly<W>(pub W);Available on crate feature
io only.Expand description
An adaptor which implements Splittable for any AsyncWrite, with the
read half being ().
This can be used to create a framed sink with only a writer, using
the AsyncWriteExt::framed or AsyncWriteExt::bytes method.
Tuple Fields
0: WTrait Implementations
impl<W> AsyncWrite for WriteOnly<W>where
W: AsyncWrite,
impl<W> AsyncWrite for WriteOnly<W>where
W: AsyncWrite,
async fn flush(&mut self) -> Result<(), Error>
async fn flush(&mut self) -> Result<(), Error>
Attempts to flush the object, ensuring that any buffered data reach
their destination.
async fn shutdown(&mut self) -> Result<(), Error>
async fn shutdown(&mut self) -> Result<(), Error>
Initiates or attempts to shut down this writer, returning success when
the I/O connection has completely shut down.
async fn write_vectored<T>(&mut self, buf: T) -> BufResult<usize, T>where
T: IoVectoredBuf,
async fn write_vectored<T>(&mut self, buf: T) -> BufResult<usize, T>where
T: IoVectoredBuf,
Like
write, except that it write bytes from a buffer implements
IoVectoredBuf into the source. Read moreimpl<W> Splittable for WriteOnly<W>
impl<W> Splittable for WriteOnly<W>
type ReadHalf = ()
type ReadHalf = ()
The type of the read half, which normally implements
AsyncRead or
AsyncReadAt.type WriteHalf = W
type WriteHalf = W
The type of the write half, which normally implements
AsyncWrite or
AsyncWriteAt.fn split(
self,
) -> (<WriteOnly<W> as Splittable>::ReadHalf, <WriteOnly<W> as Splittable>::WriteHalf)
fn split( self, ) -> (<WriteOnly<W> as Splittable>::ReadHalf, <WriteOnly<W> as Splittable>::WriteHalf)
Consumes
self and returns a tuple containing separate read and write
halves. Read moreAuto Trait Implementations
impl<W> Freeze for WriteOnly<W>where
W: Freeze,
impl<W> RefUnwindSafe for WriteOnly<W>where
W: RefUnwindSafe,
impl<W> Send for WriteOnly<W>where
W: Send,
impl<W> Sync for WriteOnly<W>where
W: Sync,
impl<W> Unpin for WriteOnly<W>where
W: Unpin,
impl<W> UnsafeUnpin for WriteOnly<W>where
W: UnsafeUnpin,
impl<W> UnwindSafe for WriteOnly<W>where
W: UnwindSafe,