Trait AsyncReadMultiAt
pub trait AsyncReadMultiAt: AsyncReadManagedAt {
// Required method
fn read_multi_at(
&self,
len: usize,
pos: u64,
) -> impl Stream<Item = Result<Self::Buffer, Error>>;
}Available on crate feature
io only.Expand description
AsyncReadMultiAt
Async read with buffer pool and position, returns a stream of managed buffers.
Required Methods
fn read_multi_at(
&self,
len: usize,
pos: u64,
) -> impl Stream<Item = Result<Self::Buffer, Error>>
fn read_multi_at( &self, len: usize, pos: u64, ) -> impl Stream<Item = Result<Self::Buffer, Error>>
Read some bytes from this source at position and return a stream of
AsyncReadManagedAt::Buffer.
Implementation Note
- If
len== 0, implementation should use buffer’s size aslen - if
len> 0,min(len, buffer_size)will be the max number of bytes to be read each time.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.