pub trait AsyncWriteAt {
// Required method
async fn write_at<T>(&mut self, buf: T, pos: u64) -> BufResult<usize, T>
where T: IoBuf;
// Provided method
async fn write_vectored_at<T>(
&mut self,
buf: T,
pos: u64,
) -> BufResult<usize, T>
where T: IoVectoredBuf { ... }
}Available on crate feature
io only.Expand description
AsyncWriteAt
Async write with a ownership of a buffer and a position
Required Methods
Provided Methods
Sourceasync fn write_vectored_at<T>(
&mut self,
buf: T,
pos: u64,
) -> BufResult<usize, T>where
T: IoVectoredBuf,
async fn write_vectored_at<T>(
&mut self,
buf: T,
pos: u64,
) -> BufResult<usize, T>where
T: IoVectoredBuf,
Like AsyncWrite::write_vectored, except that it writes at a
specified position.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl AsyncWriteAt for [u8]
impl AsyncWriteAt for [u8]
Sourceimpl<A> AsyncWriteAt for &mut Awhere
A: AsyncWriteAt + ?Sized,
impl<A> AsyncWriteAt for &mut Awhere
A: AsyncWriteAt + ?Sized,
Implementors
impl AsyncWriteAt for &File
impl AsyncWriteAt for File
impl<A> AsyncWriteAt for Vec<u8, A>where
A: Allocator,
This implementation aligns the behavior of files. If pos is larger than
the vector length, the vectored will be extended, and the extended area will
be filled with 0.